==> virglrenderer_0.8.2.orig.tar.bz2: virglrenderer-0.8.2/src/gallium/auxiliary/tgsi/tgsi_sanity.h <==
/**************************************************************************
 * 
 * Copyright 2008 VMware, Inc.
 * All Rights Reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sub license, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 * 
 * The above copyright notice and this permission notice (including the
 * next paragraph) shall be included in all copies or substantial portions
 * of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT.
 * IN NO EVENT SHALL VMWARE AND/OR ITS SUPPLIERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 * 
 **************************************************************************/

#ifndef TGSI_SANITY_H
#define TGSI_SANITY_H

#if defined __cplusplus
extern "C" {
#endif

#include "pipe/p_compiler.h"

struct tgsi_token;

/* Check the given token stream for errors and common mistakes.
 * Diagnostic messages are printed out to the debug output, and is
 * controlled by the debug option TGSI_PRINT_SANITY (default false).
 * Returns TRUE if there are no errors, even though there could be some warnings.
 */
boolean
tgsi_sanity_check(
   const struct tgsi_token *tokens );

#if defined __cplusplus
}
#endif

#endif /* TGSI_SANITY_H */

==> virglrenderer_1.1.0.orig.tar.bz2: virglrenderer-1.1.0/src/gallium/auxiliary/tgsi/tgsi_sanity.h <==
/**************************************************************************
 * 
 * Copyright 2008 VMware, Inc.
 * All Rights Reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sub license, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 * 
 * The above copyright notice and this permission notice (including the
 * next paragraph) shall be included in all copies or substantial portions
 * of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT.
 * IN NO EVENT SHALL VMWARE AND/OR ITS SUPPLIERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 * 
 **************************************************************************/

#ifndef TGSI_SANITY_H
#define TGSI_SANITY_H

#if defined __cplusplus
extern "C" {
#endif

#include "pipe/p_compiler.h"

struct tgsi_token;

/* Check the given token stream for errors and common mistakes.
 * Diagnostic messages are printed out to the debug output, and is
 * controlled by the debug option TGSI_PRINT_SANITY (default false).
 * Returns true if there are no errors, even though there could be some warnings.
 */
bool
tgsi_sanity_check(
   const struct tgsi_token *tokens );

#if defined __cplusplus
}
#endif

#endif /* TGSI_SANITY_H */
